@@ -1,13 +1,13 @@
-# Copyrights 2009-2014 by [Mark Overmeer].
+# Copyrights 2009-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package BPM::XPDL;
 use vars '$VERSION';
-$VERSION = '0.92';
+$VERSION = '0.93';
 
 use base 'XML::Compile::Cache';
 
@@ -22,6 +22,7 @@ my %ns2version =
  , &NS_XPDL_10  => '1.0'
  , &NS_XPDL_20  => '2.0'
  , &NS_XPDL_21  => '2.1'
+ , &NS_XPDL_22  => '2.2'
  );
 
 my %info =
@@ -44,6 +45,9 @@ my %info =
  , '2.1' =>
      { prefixes => { '' => NS_XPDL_21 }
      }
+ , '2.2' =>
+     { prefixes => { '' => NS_XPDL_22 }
+     }
  );
 
 #--------
@@ -320,7 +324,6 @@ sub namespace() {shift->{namespace}}
 
 #--------
 
-
 sub create($)
 {   my ($self, $data) = @_;
     my $doc  = XML::LibXML::Document->new('1.0', 'UTF-8');
